@@ -8,11 +8,24 @@
 #ifndef FUNCTIONS_H_
 #define FUNCTIONS_H_
 
-#include<vector>
+#include <vector>
+#include <utility>
 #include <Rmath.h>
 
-/**r random number generator, code from : http://gallery.rcpp.org/articles/r-function-from-c++/*/
-inline int randWrapper(const int n) { return floor(unif_rand()*n); }
+/**r random number generator, code from : http://gallery.rcpp.org/articles/r-function-from-c++/
+ * generate an integer between 0 and n - 1
+ */
+int randWrapper(const int n);
+
+/** equivalent of std::shuffle with an R generator
+ */
+template <class RandomAccessIterator>
+void Rshuffle(RandomAccessIterator first, RandomAccessIterator last)
+{
+  for (auto i = (last-first) - 1;  i > 0; --i) {
+    std::swap (first[i], first[randWrapper(i + 1)]);
+  }
+}
 
 /**
  * search the position of i in x
@@ -20,7 +33,7 @@ inline int randWrapper(const int n) { return floor(unif_rand()*n); }
  * @param i integer which we want the position in x
  * @return the position of i in x
  */
-int positionRank(std::vector<int> const& x,int const& i);
+int positionRank(std::vector<int> const &x, int const &i);
 
 /**
  * compute  A(x,y) and G(x,y,mu)
@@ -33,7 +46,7 @@ int positionRank(std::vector<int> const& x,int const& i);
  * G(x,y,mu)= total number of good comparaison according to mu in the insertion sorting algorithm
  *
  */
-std::vector<int> comparaison(std::vector<int> const& x,std::vector<int> const& y,std::vector<int> const& mu);
+std::vector<int> comparaison(std::vector<int> const &x, std::vector<int> const &y, std::vector<int> const &mu);
 
 /**
  * compute the conditional probability  p(x|y;mu,p)
@@ -43,21 +56,21 @@ std::vector<int> comparaison(std::vector<int> const& x,std::vector<int> const& y
  * @param p probability of making a good comparaison
  * @return p(x|y;mu,p)
  */
-double probaCond(std::vector<int> const& x,std::vector<int> const& y,std::vector<int> const& mu,double const& p);
+double probaCond(std::vector<int> const &x, std::vector<int> const &y, std::vector<int> const &mu, double const &p);
 
 /**
  * factorial function (recursive)
  * @param m an integer >0
  * @return m!
  */
-int factorial(int const& nombre);
+int factorial(int const &nombre);
 
 /**
  * compute all the factorial from 1! to m!
  * @param m a positive integer
  * @return a vector of size m containing all the factorial from 1! to m!
  */
-std::vector<int> tab_factorial(int const& m);
+std::vector<int> tab_factorial(int const &m);
 
 /**
  *-----------rang->index------------
@@ -66,7 +79,7 @@ std::vector<int> tab_factorial(int const& m);
  * @param  tabFactorial \see tab_factorial
  * @return index
  */
-int rank2index(std::vector<int> const& rang,std::vector<int> const& tabFactorial);
+int rank2index(std::vector<int> const &rang, std::vector<int> const &tabFactorial);
 
 /**
  *-----------rang->index------------
@@ -75,7 +88,7 @@ int rank2index(std::vector<int> const& rang,std::vector<int> const& tabFactorial
  * @param  tabFactorial @see tab_factorial
  * @return vector of index
  */
-std::vector<int> rank2index(std::vector<std::vector<int> > const& listeRang,std::vector<int> const& tabFact);
+std::vector<int> rank2index(std::vector<std::vector<int>> const &listeRang, std::vector<int> const &tabFact);
 
 /**
  * conversion index->rank
@@ -88,10 +101,9 @@ std::vector<int> rank2index(std::vector<std::vector<int> > const& listeRang,std:
  *
  * m!= m m-1 .. 1
  */
-std::vector<int> index2rank(int index,int const& m,std::vector<int> const& tabFactorial);
-std::vector<int> index2rankb(int index,int const& m,std::vector<int> const& tabFactorial);
-std::vector<int> index2rank(int index,int const& m);
-
+std::vector<int> index2rank(int index, int const &m, std::vector<int> const &tabFactorial);
+std::vector<int> index2rankb(int index, int const &m, std::vector<int> const &tabFactorial);
+std::vector<int> index2rank(int index, int const &m);
 
 /**
  * Return a vector containing the index of order of presentation y for which we have to compute probability
@@ -102,7 +114,7 @@ std::vector<int> index2rank(int index,int const& m);
  * p(x|y;mu,p) doesn't change if the 2 first element of y are inverted
  * So we compute probabilities for the half of y
  */
-std::vector<int> listeSigma(int const& m,std::vector<int> const& tabFactorial);
+std::vector<int> listeSigma(int const &m, std::vector<int> const &tabFactorial);
 
 /**
  * invert a rank (1 2 3 become 3 2 1)
@@ -110,7 +122,7 @@ std::vector<int> listeSigma(int const& m,std::vector<int> const& tabFactorial);
  * @param m size of the rank
  */
 void inverseRang(std::vector<int> &rang);
-void inverseRang(std::vector<int> &rang,int const& m);
+void inverseRang(std::vector<int> &rang, int const &m);
 
 /**
  * Compute the BIC
@@ -118,7 +130,7 @@ void inverseRang(std::vector<int> &rang,int const& m);
  * @param nbDonnees total number of data
  * @return BIC
  */
-double BIC(double loglikelihood,int nbDonnees,int nbParam);
+double BIC(double loglikelihood, int nbDonnees, int nbParam);
 
 /**
  * compute the Rand index of 2 partitions
@@ -126,7 +138,7 @@ double BIC(double loglikelihood,int nbDonnees,int nbParam);
  * @param z2 partition
  * @return a double, the Rand index
  */
-double indiceRand(std::vector<int> const& z1,std::vector<int>  const& z2);
+double indiceRand(std::vector<int> const &z1, std::vector<int> const &z2);
 
 /**
  * conversion from ordering representation to ranking representation
@@ -134,7 +146,7 @@ double indiceRand(std::vector<int> const& z1,std::vector<int>  const& z2);
  * @param m size of the rank
  * @return a rank : the ranking representation of x
  */
-std::vector<int> order2rank(std::vector<int> const& x,int const& m);
+std::vector<int> order2rank(std::vector<int> const &x, int const &m);
 
 /**
  *  Compute the Kendall's distance between 2 ranks (in ordering representation)
@@ -142,7 +154,7 @@ std::vector<int> order2rank(std::vector<int> const& x,int const& m);
  * @param y a rank in ordering representation of the same size than x
  * @return an integer, the kendall distance between x and y
  */
-int distanceKendall(std::vector<int> const& x,std::vector<int> const& y);
+int distanceKendall(std::vector<int> const &x, std::vector<int> const &y);
 
 /**
  * sort the parameters in order that the first cluster is the cluster with the more little ndex of mu
@@ -157,9 +169,8 @@ int distanceKendall(std::vector<int> const& x,std::vector<int> const& y);
  * listeMu, p, prop and z are modify if necessary
  *
  */
-void tri_insertionMulti(std::vector<int> &mu,std::vector<double> &prop,std::vector<std::vector<double> > &p,
-		std::vector<std::vector<std::vector<int> > > &listeMu,std::vector<int> &z,int const& g,int const& d,int const& n);
-
+void tri_insertionMulti(std::vector<int> &mu, std::vector<double> &prop, std::vector<std::vector<double>> &p,
+                        std::vector<std::vector<std::vector<int>>> &listeMu, std::vector<int> &z, int const &g, int const &d, int const &n);
 
 /**
  * simulation of a n-sample of ISR(mu,p)
@@ -169,15 +180,15 @@ void tri_insertionMulti(std::vector<int> &mu,std::vector<double> &prop,std::vect
  * @param p probability of a good comapraison
  * @return a n-sample of ISR(mu,p)
  */
-std::vector<std::vector<int> > simulISR(int const& n,int const& m,std::vector<int> const& mu, double const& p);
+std::vector<std::vector<int>> simulISR(int const &n, int const &m, std::vector<int> const &mu, double const &p);
 
 /**
  * compute frequence of a data set
  * @param listeRang data
  * @return a pair with the unique rank and the frequence of each unique rank
  */
-std::pair<std::vector<std::vector<std::vector<int> > >,std::vector<int> >
-freqMulti(std::vector<std::vector<std::vector<int> > > const& listeRang);
+std::pair<std::vector<std::vector<std::vector<int>>>, std::vector<int>>
+freqMulti(std::vector<std::vector<std::vector<int>>> const &listeRang);
 
 /**
  * compute probability of x according to multivariate ISR
@@ -186,6 +197,6 @@ freqMulti(std::vector<std::vector<std::vector<int> > > const& listeRang);
  * @param pi dispersion parameter for each dimension
  * @return p(x;mu,pi)
  */
-double proba(std::vector<std::vector<int> > const& x, std::vector<std::vector<int> > const& mu, std::vector<double> const& pi);
+double proba(std::vector<std::vector<int>> const &x, std::vector<std::vector<int>> const &mu, std::vector<double> const &pi);
 
 #endif /* FUNCTIONS_H_ */
